:py:mod:`simplemseed.exceptions`
================================

.. py:module:: simplemseed.exceptions

.. autodoc2-docstring:: simplemseed.exceptions
   :allowtitles:

Module Contents
---------------

API
~~~

.. py:exception:: CodecException(message)
   :canonical: simplemseed.exceptions.CodecException

   Bases: :py:obj:`Exception`

.. py:exception:: SteimException(message)
   :canonical: simplemseed.exceptions.SteimException

   Bases: :py:obj:`simplemseed.exceptions.CodecException`

.. py:exception:: UnsupportedCompressionType(message)
   :canonical: simplemseed.exceptions.UnsupportedCompressionType

   Bases: :py:obj:`simplemseed.exceptions.CodecException`
